# BullshitGenerator
forked from https://github.com/menzi11/BullshitGenerator

## Update
- modify to support multi-language
- Flexible architecture

## Usage
### pip
`pip install bsgen`  
Then,run
`bsgen`

### clone and run
git clone this project and run `/bsgen/generate.py`